import processing.video.*;
import controlP5.*;
import javax.swing.*; 
import java.awt.Insets;


public class CaptureSelector extends JFrame {

  final String TITLE = "Capture Selector";
  final int WIDTH = 540;
  final int BASE_HEIGHT = 80;
  final int DEFAULT_POSX = 200;
  final int DEFAULT_POSY = 200;  
  final int DEFAULT_CAPTURE_INDEX = 0;  
  final int BAR_HEIGHT = 21;
  final int NUM = 20;

  SecondApplet s;
  PApplet parent;
  Capture capture;  
  String[] list;  
  int list_height = 0;
  
  String default_capture;
  int capture_index = DEFAULT_CAPTURE_INDEX;

  public CaptureSelector(PApplet _applet) {
    initThis( _applet, "dummy" );    
  }

  public CaptureSelector(PApplet _applet, String _default_capture ) {
    initThis( _applet, _default_capture );    
  }

  void initThis(PApplet _parent, String _default_capture ) {
    this.parent = _parent;
    this.default_capture = _default_capture;
    this.list = Capture.list();  
    this.list_height = BAR_HEIGHT*min(NUM, list.length+1);

    // setting of applet
    s = new SecondApplet();
    add(s);
    s.init();

    // setting of frame
    Insets insets = frame.getInsets();    
    setSize( WIDTH + insets.left + insets.right, BASE_HEIGHT + list_height + insets.top + insets.bottom );
    setResizable(false);
    setLocation(DEFAULT_POSX, DEFAULT_POSY);
    setTitle(TITLE);

    // Find index by default parameters
    for ( int i=0; i<list.length; i++) {
      if (list[i].equals(default_capture)) {
        capture_index = i;
        break;
      }
    }
  }
  
  public Capture getCapture() {
    return capture;
  }

  private class SecondApplet extends PApplet {
    final String FONT = "Verdata";
    final int FONT_SIZE = 20;
    final int dl_FONT_SIZE = 15;

    PFont myFont;
    ControlP5 cp5;
    DropdownList dl_list;

    public void setup() {

      // Font setting
      myFont = parent.createFont(FONT, FONT_SIZE);
      textFont(myFont);
      textSize(FONT_SIZE);

      // setting of controlP5
      cp5 = new ControlP5(this);
      cp5.setControlFont(new ControlFont(myFont, dl_FONT_SIZE)); 

      // setting of dropdownlist)
      dl_list = cp5.addDropdownList("dl-capture-list");
      if ( list.length <= 0 ) { 
        dl_list.captionLabel().set("not found");
      } else {
        dl_list.captionLabel().set("capture configuration");
      }
      dl_list.setScrollbarWidth(20);
      dl_list.setPosition(20, 70);
      dl_list.setWidth(500);
      dl_list.setHeight(list_height);
      dl_list.setBarHeight(21);
      dl_list.setItemHeight(22);
      dl_list.valueLabel().style().marginTop = 3;
      dl_list.toUpperCase(false);
      for (int i=0; i<list.length; i++) {
        dl_list.addItem(list[i], i);
      }
      dl_list.setIndex(capture_index);
    }

    public void draw() {
      background(200);
      fill(0);
      text("Select capture configuration", 14, 30 );
    }    

    void controlEvent(ControlEvent event) {
      if (event.isGroup()) {
        if ( dl_list != null) {
          capture_index = (int)(dl_list.getValue());
        }
        if (capture != null) {
          capture.stop();
        }
        try {
          capture = new Capture(parent, list[capture_index]);
          capture.start();
        } 
        catch (Exception e) {
        }
      }
    }
  }
}
